package com.dsic.gj_erp.service.jhgk.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dsic.gj_erp.bean.jcsj.DmBom;
import com.dsic.gj_erp.bean.jcsj.DmCbxxp;
import com.dsic.gj_erp.bean.jhgk.*;
import com.dsic.gj_erp.bean.jhgk.excel.JhxfExcel;
import com.dsic.gj_erp.bean.pgd.PgdTzjh;
import com.dsic.gj_erp.mapper.jhgk.DmSygdMxMapper;
import com.dsic.gj_erp.mapper.jhgk.DmSygdxqMapper;
import com.dsic.gj_erp.service.jcsj.DmBomService;
import com.dsic.gj_erp.service.jcsj.DmCbxxpService;
import com.dsic.gj_erp.service.pgd.PgdTzjhService;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import java.util.stream.Collectors;

@Service
@AllArgsConstructor
public class YdjhImportService extends ServiceImpl<DmSygdMxMapper, DmSygdMx> {

    private final DmSygdxqMapper sygdxqMapper;
    private final IYdjhImportService importService;
    private final DmBomService bomService;
    private final DmCbxxpService dmCbxxpService;
    private final PgdTzjhService tzjhService;

    public List<YdjhImport> list(String begin, String end) {
        return importService.list(Wrappers.<YdjhImport>lambdaQuery()
                .between(YdjhImport::getFdxq, begin, end).or().between(YdjhImport::getQwbjs, begin, end)
                .orderByAsc(YdjhImport::getId)
        );
    }

    @Transactional(rollbackFor = Exception.class)
    public void handler(List<JhxfExcel> objList) {
        List<YdjhImport> ydjhImports = this.executeYdjhImport(objList);

        ydjhImports.forEach(item->{
            String dcPl=item.getDcPl();
            if (item.getDcPl().contains("Q")) {
                dcPl=item.getDcPl().replace("Q", "");
            }

            try {
                dcPl = String.format("%03d", Integer.parseInt(dcPl));
            } catch (Exception ignored) {
            }

            baseMapper.delete(new QueryWrapper<DmSygdMx>()
                    .eq("dc_ch", item.getDcCh())
                    .eq("dc_pl", dcPl)
            );
        });
//        List<YdjhImport> qwb = ydjhImports.stream()
//                .filter(YdjhImport::isAvailable)
//                .filter(item -> !item.getDcPl().contains("-"))//去除T型材
//                .filter(item -> !item.getDcPl().contains("/"))//去除T型材
//                .filter(item -> StrUtil.isNotEmpty(item.getDcFd()))
//                .filter(item -> item.getDcPl().contains("Q")).collect(Collectors.toList());
//        this.execute(qwb);

        List<YdjhImport> list = ydjhImports.stream()
                .filter(YdjhImport::isAvailable)
                .filter(item -> !item.getDcPl().contains("-"))//去除T型材
                .filter(item -> !item.getDcPl().contains("/"))//去除T型材
                .filter(item -> StrUtil.isNotEmpty(item.getDcFd()))
                .filter(item -> !item.getDcPl().contains("Q")).collect(Collectors.toList());
        this.execute(list);

        ydjhImports.forEach(importService::saveOrUpdate);

        //没有基础数据的计划生成图纸计划
        List<PgdTzjh> tzjhList = new ArrayList<>();
        ydjhImports.stream()
            .filter(item -> !StrUtil.equals(item.getExtData(), "1"))
            .forEach(item->{
                String dcPl=item.getDcPl();
                if (item.getDcPl().contains("Q")) {
                    dcPl=item.getDcPl().replace("Q", "");
                }

                try {
                    dcPl = String.format("%03d", Integer.parseInt(dcPl));
                } catch (Exception ignored) {
                }
                if (StrUtil.isNotEmpty(item.getDcFd())){
                    String[] dcfd=item.getDcFd().split("\\.");
                    for(String dcFd:dcfd){
                        PgdTzjh dmTzjh = PgdTzjh.of(item,dcPl, dcFd);
                        tzjhList.add(dmTzjh);
                    }
                }
            });
        tzjhService.saveBatch(tzjhList);

    }

    @Transactional(rollbackFor = Exception.class)
    public List<YdjhImport> executeYdjhImport(List<JhxfExcel> objList) {
        Map<String, YdjhImport> map = new HashMap<>();
        List<YdjhImport> list = new ArrayList<>();
        for (int i = 0; i < objList.size(); i++) {
            JhxfExcel item = objList.get(i);
            YdjhImport jh = new YdjhImport();
            BeanUtil.copyProperties(item, jh);
            jh.setImportIndex(i);
            YdjhImport _jh = map.get(jh.getDcCh() + jh.getDcPl());
            if (_jh != null) {
                if (_jh.getFdxq() != null && jh.getFdxq() == null) {
                    jh.setFdxq(_jh.getFdxq());
                }
                if (_jh.getFdxq() == null && jh.getFdxq() != null) {
                    _jh.setFdxq(jh.getFdxq());
                }
                if (_jh.getQwbjs() != null && jh.getQwbjs() == null) {
                    jh.setQwbjs(_jh.getQwbjs());
                }
                if (_jh.getQwbjs() == null && jh.getQwbjs() != null) {
                    _jh.setQwbjs(jh.getQwbjs());
                }
            } else {
                map.put(jh.getDcCh() + jh.getDcPl(), jh);
            }

            importService.remove(new QueryWrapper<YdjhImport>()
                    .eq("dc_ch", jh.getDcCh())
                    .eq("dc_pl", jh.getDcPl())
            );
            jh.setZt("0");
            list.add(jh);
        }
        return list;
    }

    /**
     * 月度计划导入,不使用月度计划只能排产功能前提下使用该功能导入月度计划
     */
    @Transactional(rollbackFor = Exception.class)
    public void execute(List<YdjhImport> objList) {
        HashMap<String, Object> _map = new HashMap<>();
        objList.parallelStream().forEach(item->{
            String dcPl=item.getDcPl();
            if (item.getDcPl().contains("Q")) {
                dcPl=item.getDcPl().replace("Q", "");
                item.setQwbBs(true);
            }

            try {
                dcPl = String.format("%03d", Integer.parseInt(dcPl));
            } catch (Exception ignored) {
            }
            String[] dcfd=item.getDcFd().split("\\.");

            String dcFd=dcfd[0];

            Object o = _map.get(item.getDcCh() + item.getDcPl());
            if(o==null){
                _map.put(item.getDcCh() + item.getDcPl(),1);
            }else{
                return;
            }

            List<DmBom> bomList = bomService.getBomWithYlbs(item.getDcCh(), dcPl);

            String dcCh;
            //基础数据未导入,使用目标船只
            if (ObjUtil.isEmpty(bomList)) {
                DmCbxxp one = dmCbxxpService.getOne(Wrappers.<DmCbxxp>lambdaQuery()
                        .eq(DmCbxxp::getCbbm, item.getDcCh())
                );
                if (one != null) {
                    dcCh = one.getCbbm();
                    item.setExtData(dcCh);//使用目标船只基础数据
                    bomList = bomService.getBomWithYlbs(dcCh, dcPl);
                    if (ObjUtil.isEmpty(bomList)) {
                        DmSygdMx dmSygdMx = this.initDefault(item,dcFd,dcPl);
                        dmSygdMx.setDcCh1(dcCh);
                        this.save(dmSygdMx);
                        item.setExtData("0");//无基础数据
                        return;
                    }
                } else {
                    item.setExtData("0");//无基础数据
                    DmSygdMx dmSygdMx = this.initDefault(item,dcFd,dcPl);
                    this.save(dmSygdMx);
                    return;
                }
            } else {
                item.setExtData("1");//有基础数据
            }

            List<DmSygdxq> dmSygdxqs = sygdxqMapper.selectList(Wrappers.<DmSygdxq>lambdaQuery()
                    .eq(DmSygdxq::getDcCh, item.getDcCh()).eq(DmSygdxq::getDcPl, dcPl));

            HashMap<Object, DmSygdxq> map = new HashMap<>();
            for (DmSygdxq xq : dmSygdxqs) {
                String pl = xq.getDcPl();
                String fd = xq.getDcFd();
                map.put(item.getDcCh() + pl + fd, xq);
            }
            List<DmSygdMxLj> ljList = this.initLj(item.getDcCh(), map, bomList);

            List<DmSygdMx> sygdMxes;
            if (item.getQwbBs()) {
                ljList=ljList.stream().filter(it -> "3".equals(it.getTzbh().substring(5, 6)))
                        .collect(Collectors.toList());
                sygdMxes = this.initBySl(item, ljList,dcFd);
            } else {
                ljList=ljList.stream().filter(it -> !"3".equals(it.getTzbh().substring(5, 6)))
                        .collect(Collectors.toList());
                sygdMxes = this.initBySl(item, ljList,dcFd);
            }

            List<DmSygdMx> addList = new ArrayList<>(sygdMxes);

            if (item.getPkqgjs() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "7".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateByYklm(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "7".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initByYklm(item, _ljlist,dcFd,dcPl);
                    addList.addAll(list);
                }

//                List<DmSygdMx> _sygdMxes1 = sygdMxes.stream().filter(it -> "8".equals(it.getKw())).collect(Collectors.toList());
//                if (!_sygdMxes1.isEmpty()) {
//                    for (DmSygdMx dmSygdMx : _sygdMxes1) {
//                        this.updateByYksk(item, dmSygdMx);
//                    }
//                } else {
//                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "8".equals(it.getKw())).collect(Collectors.toList());
//                    if (!_ljlist.isEmpty()) {
//                        List<DmSygdMx> list = this.initByYksk(item, _ljlist,dcFd,dcPl);
//                        addList.addAll(list);
//                    }
//                }
            }
//
            if (item.getLmqgks() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "5".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateByEklm(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "5".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initByEklmbs(item, _ljlist,dcFd,dcPl);
                    addList.addAll(list);
                }
            }

            if (item.getEkskks() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "9".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateByEksk(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "9".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initByEksk(item, _ljlist,dcFd,dcPl);
                    addList.addAll(list);
                }
            }

            if (item.getSkskqgks() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "14".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateBySksk(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "14".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initBySksk(item, _ljlist,dcFd,dcPl);
                    addList.addAll(list);
                }
            }

            if (item.getPtks() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "6".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateBySkpt(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "6".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initBySkpt(item, _ljlist,dcFd,dcPl);
                    addList.addAll(list);
                }
            }

            if (item.getSkqgks() != null) {
                List<DmSygdMx> _sygdMxes = sygdMxes.stream().filter(it -> "15".equals(it.getKw())).collect(Collectors.toList());
                if (!_sygdMxes.isEmpty()) {
                    for (DmSygdMx sygdMx : _sygdMxes) {
                        this.updateBySkbs(item, sygdMx);
                    }
                } else {
                    List<DmSygdMxLj> _ljlist = ljList.stream().filter(it -> "15".equals(it.getKw())).collect(Collectors.toList());
                    List<DmSygdMx> list = this.initBySkbs(item, _ljlist,dcFd,dcPl);
                    addList.addAll(list);
                }
            }
            this.saveBatch(addList);
        });
    }

    private List<DmSygdMx> initBySl(YdjhImport item, List<DmSygdMxLj> bomList,String dcFd) {
        List<DmSygdMx> addList = new ArrayList<>();

        if (item.getSl() != null) {
            ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                    Collectors.collectingAndThen(
                            Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
            );
            for (DmSygdMxLj dmSygdMxLj : list) {
                DmSygdMx init = this.initByOther(item, dmSygdMxLj);
                if (item.getQwbBs()) {
                    init.setQbs("1");
                    init.setJssj(item.getQwbjs());
                }
                addList.add(init);
            }
        }
        return addList;
    }

    private List<DmSygdMx> initByYklm(YdjhImport item, List<DmSygdMxLj> bomList,String dcFd,String dcPl) {
        List<DmSygdMx> addList = new ArrayList<>();
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initByOther(item, dmSygdMxLj);
            this.updateByYklm(item,init);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initByYksk(YdjhImport item, List<DmSygdMxLj> bomList,String dcFd,String dcPl) {
        List<DmSygdMx> addList = new ArrayList<>();
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initByOther(item, dmSygdMxLj);
            this.updateByYksk(item,init);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initByEklmbs(YdjhImport item, List<DmSygdMxLj> bomList,String dcFd,String dcPl) {
        List<DmSygdMx> addList = new ArrayList<>();
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initByOther(item, dmSygdMxLj);
            this.updateByEklm(item,init);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initByEksk(YdjhImport item, List<DmSygdMxLj> bomList,String dcFd,String dcPl) {
        List<DmSygdMx> addList = new ArrayList<>();
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initByOther(item, dmSygdMxLj);
            this.updateByEksk(item,init);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initBySksk(YdjhImport item, List<DmSygdMxLj> bomList,String dcFd,String dcPl) {
        List<DmSygdMx> addList = new ArrayList<>();
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initByOther(item, dmSygdMxLj);
            this.updateBySksk(item,init);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initBySkpt(YdjhImport item, List<DmSygdMxLj> bomList,String dcFd,String dcPl) {
        List<DmSygdMx> addList = new ArrayList<>();
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initByOther(item, dmSygdMxLj);
            this.updateBySkpt(item,init);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private List<DmSygdMx> initBySkbs(YdjhImport item, List<DmSygdMxLj> bomList,String dcFd,String dcPl) {
        List<DmSygdMx> addList = new ArrayList<>();
        ArrayList<DmSygdMxLj> list = bomList.stream().collect(
                Collectors.collectingAndThen(
                        Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(DmSygdMxLj::getUniqueData))), ArrayList::new)
        );
        for (DmSygdMxLj dmSygdMxLj : list) {
            DmSygdMx init = this.initByOther(item, dmSygdMxLj);
            this.updateBySkbs(item,init);
            if (item.getQwbBs()) {
                init.setQbs("1");
                init.setJssj(item.getQwbjs());
            }
            addList.add(init);
        }
        return addList;
    }

    private void updateByYklm(YdjhImport item, DmSygdMx dmSygdMx) {
        dmSygdMx.setKw("7");
        dmSygdMx.setQgrq(item.getYkpkjs());
        dmSygdMx.setHxrq(item.getYkpkjs());
    }

    private void updateByYksk(YdjhImport item, DmSygdMx dmSygdMx) {
        dmSygdMx.setKw("8");
        dmSygdMx.setQgrq(item.getYkpkjs());
        dmSygdMx.setHxrq(item.getYkpkjs());
    }

    private void updateByEklm(YdjhImport item, DmSygdMx dmSygdMx) {
        dmSygdMx.setKw("5");
        dmSygdMx.setQgrq(item.getLmqgks());
        dmSygdMx.setHxrq(item.getLmqgks());
    }

    private void updateByEksk(YdjhImport item, DmSygdMx dmSygdMx) {
        dmSygdMx.setKw("9");
        dmSygdMx.setQgrq(item.getEkskks());
        dmSygdMx.setHxrq(item.getEkskks());
    }

    private void updateBySksk(YdjhImport item, DmSygdMx dmSygdMx) {
        dmSygdMx.setKw("14");
        dmSygdMx.setQgrq(item.getSkskqgks());
        dmSygdMx.setHxrq(item.getSkskqgks());
        dmSygdMx.setQgjs(item.getSkpkjs());
        dmSygdMx.setQjgrq(item.getQptjs());
    }

    private void updateBySkpt(YdjhImport item, DmSygdMx dmSygdMx) {
        dmSygdMx.setKw("6");
        dmSygdMx.setQgrq(item.getPtks());
    }

    private void updateBySkbs(YdjhImport item, DmSygdMx dmSygdMx) {
        dmSygdMx.setKw("15");
        dmSygdMx.setQgrq(item.getSkqgks());
        dmSygdMx.setQgrq(item.getSkqgks());
    }

    private DmSygdMx initDefault(YdjhImport item,String dcFd,String dcPl) {
        DmSygdMx dmSygdMx = new DmSygdMx();
        dmSygdMx.setDcCh(item.getDcCh());
        if(!"1".equals(item.getExtData())){
            dmSygdMx.setDcCh1(item.getExtData());
        }
        dmSygdMx.setDcPl(dcPl);
        dmSygdMx.setDcFd(dcFd);
        dmSygdMx.setJssj(item.getFdxq());
        dmSygdMx.setSlrq(item.getSl());
        dmSygdMx.setXcpw(item.getXcpw());
        dmSygdMx.setPwrq(item.getPw());
        dmSygdMx.setLlrq(item.getPw());
        if (item.getQwbBs()) {
            dmSygdMx.setQbs("1");
            dmSygdMx.setJssj(item.getQwbjs());
        }
        return dmSygdMx;
    }

    private DmSygdMx initByOther(YdjhImport item, DmSygdMxLj bom) {
        DmSygdMx dmSygdMx = DmSygdMx.ofWithDmSygdMxlj(bom);
        dmSygdMx.setDcCh(item.getDcCh());
        if(!"1".equals(item.getExtData())){
            dmSygdMx.setDcCh1(item.getExtData());
        }
        dmSygdMx.setDcPl(bom.getPl());
        dmSygdMx.setDcFd(bom.getFd());
        dmSygdMx.setSlrq(item.getSl());
        dmSygdMx.setXcpw(item.getXcpw());
        dmSygdMx.setPwrq(item.getPw());
        dmSygdMx.setJssj(item.getFdxq());
        dmSygdMx.setSlrq(item.getSl());
        dmSygdMx.setXcpw(item.getXcpw());
        dmSygdMx.setPwrq(item.getPw());
        dmSygdMx.setLlrq(item.getPw());
        if (item.getQwbBs()) {
            dmSygdMx.setQbs("1");
            dmSygdMx.setJssj(item.getQwbjs());
        }
        return dmSygdMx;
    }

    /**
     * @param dcCh    月度计划导入的船号
     * @param bomList 有可能由目标船只获取
     */
    private List<DmSygdMxLj> initLj(String dcCh, HashMap<Object, DmSygdxq> map, List<DmBom> bomList) {
        List<DmSygdMxLj> list = new ArrayList<>();

        for (DmBom bom : bomList) {
            DmSygdxq dmSygdxq = map.get(dcCh + bom.getPl() + bom.getFd());
            DmSygdMxLj dmSygdMxLj = new DmSygdMxLj();
            dmSygdMxLj.setDcch(dcCh);
            dmSygdMxLj.setPl(bom.getPl());
            dmSygdMxLj.setFd(bom.getFd());
            if (dmSygdxq != null) {
                dmSygdMxLj.setXzglxq(dmSygdxq.getXzglxq());
                dmSygdMxLj.setDzglxq(dmSygdxq.getDzglxq());
            }
            if (!dcCh.equals(bom.getDcch())) {
                dmSygdMxLj.setMbch(bom.getDcch());
            }
            BeanUtil.copyProperties(bom, dmSygdMxLj);

            list.add(dmSygdMxLj);
        }
        return list;
    }
}
